
===========
Media usage
===========

Leonardo CMS has highly adopted Django-Filer.

Leonardo has defined some common media Content Types which are basically ``media.File`` and some meaningful translations.

Media Models:

* Folder
* FolderPermission
* File
* Image
* Document
* Vector
* Video
* Flash

Media Translations:

* FolderTranslation
* DocumentTranslation
* VectorTranslation
* VideoTranslation
* ImageTranslation